@@ -3,7 +3,7 @@ from django.db import models
 
 
 class AbstractUUIDAsPK(models.Model):
-    uuid = models.UUIDField(default=uuid.uuid4, primary_key=True)
+    id = models.UUIDField(default=uuid.uuid4, primary_key=True, editable=False)
 
     class Meta:
         abstract = True
